getHistoryChangedCallback abstract method
Get the history changed callback from widget properties Returns null if not provided by the widget
Implementation
ValueChanged<List<Color>>? getHistoryChangedCallback();
Get the history changed callback from widget properties Returns null if not provided by the widget
ValueChanged<List<Color>>? getHistoryChangedCallback();