ItemConfig class
Visual configuration for individual dropdown items.
Controls the look and feel of each row in the Menu overlay, including internal padding, text alignment, background colour, corner radius, border, and elevation.
ItemConfig(
alignment: Aligned.left,
backgroundColour: Colours.white,
elevation: 2,
)
Constructors
- ItemConfig({EdgeInsetsGeometry padding = const EdgeInsetsGeometry.all(10), Aligned alignment = Aligned.center, Colour backgroundColour = Colours.white, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10)), Border border = const Border(), double elevation = 5})
-
const
Properties
- alignment → Aligned
-
final
- backgroundColour → Colour
-
final
- border → Border
-
final
- borderRadius → BorderRadius
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited